#
# spec file for package kdiskmark
#
# Copyright (c) 2022 SUSE LLC
# Copyright (c) 2020, Dmitry Sidorov <jonmagon@gmail.com>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _singleapplication_version 3.3.4
Name:           kdiskmark
Version:        3.1.4
Release:        1.6
Summary:        A simple open-source disk benchmark tool for Linux distros
License:        GPL-3.0-only
URL:            https://github.com/JonMagon/KDiskMark
Source0:        %{url}/archive/%{version}.tar.gz#/KDiskMark-%{version}.tar.gz
# SingleApplication is licensed under MIT
Source1:        https://github.com/itay-grudev/SingleApplication/archive/v%{_singleapplication_version}.tar.gz#/SingleApplication-%{_singleapplication_version}.tar.gz
BuildRequires:  extra-cmake-modules
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  update-desktop-files
BuildRequires:  cmake(PolkitQt5-1)
BuildRequires:  cmake(Qt5LinguistTools)
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  cmake(Qt5DBus)
BuildRequires:  cmake(Qt5Network)
Requires:       fio
Provides:       bundled(singleapplication) = %{_singleapplication_version}

%description
KDiskMark is an HDD and SSD benchmark tool with a very friendly graphical user interface.

%prep
%setup -q -n KDiskMark-%{version} -a1
mv SingleApplication-%{_singleapplication_version}/* src/singleapplication/

%build
%cmake_kf5 -d build
%cmake_build

%install
%kf5_makeinstall -C build

%suse_update_desktop_file -i %{name} System Filesystem
%find_lang %{name} --with-qt

%files
%license LICENSE
%doc README.md
%{_kf5_applicationsdir}/%{name}.desktop
%{_kf5_bindir}/%{name}
%{_kf5_iconsdir}/hicolor
%{_kf5_iconsdir}/hicolor/*/*/*
%dir %{_kf5_sharedir}/%{name}
%dir %{_kf5_sharedir}/%{name}/%{name}
%{_kf5_sharedir}/%{name}/%{name}/translations
# Helper files
%{_libexecdir}/kdiskmark_helper
%{_kf5_dbuspolicydir}/dev.jonmagon.kdiskmark.helperinterface.conf
%{_kf5_sharedir}/dbus-1/system-services/dev.jonmagon.kdiskmark.helperinterface.service
%{_kf5_sharedir}/polkit-1/actions/dev.jonmagon.kdiskmark.helper.policy

%changelog
* Mon Jun 19 2023 Dmitry Sidorov <jonmagon@gmail.com>
- Update to version 3.1.4
  * Fixed config directory name to ~/.config/kdiskmark
  * Hungarian localization correction
  * Dutch localization
* Sat Apr 15 2023 Dmitry Sidorov <jonmagon@gmail.com>
- Update to version 3.1.3
  * Benchmark file name is randomly generated
  * Fixed the device list template when changing the locale
  * Japanese localization
* Fri Sep 16 2022 Dmitry Sidorov <jonmagon@gmail.com>
- Update to version 3.1.2
  * Fixed visual glitch when scrolling the storage list
  * Polish localization correction
  * Swedish localization
* Fri Sep  9 2022 Dmitry Sidorov <jonmagon@gmail.com>
- Update to version 3.1.1
  * Fixed helper crash on completion of benchmarking
* Tue Sep  6 2022 Dmitry Sidorov <jonmagon@gmail.com>
- Update to version 3.1.0
  * Prevent multiple instances from being opened
  * Progress bar styles: Fusion, for light/dark theme and system one
  * Stylized design of the storage list
  * Update the storage list by changing the language
  * Prevent a line break in the dialog for a path contains a hyphen
  * Optional O_DIRECT flag
  * Migrated from KAuth to PolicyKit
  * The helper runs only if necessary
  * Pre-create a benchmark file only once before tests
  * Bring back the ability to specify the directory manually
  * Localization updated
* Wed Aug 24 2022 Dmitry Sidorov <jonmagon@gmail.com>
- Update to version 3.0.0
  * Benchmarking is performed within the helper
  * Stored configuration
  * Configurable pattern of each test
  * Region-specific numeric formatting
  * Default and NVMe presets
  * Changeable test data: random or zeros
  * Demo profile
  * Ability to perform read and write tests separately
  * Button to refresh the storage list
  * Turkish and Hungarian localization
  * The occupied space is displayed instead of free space
* Sun Mar 20 2022 Christophe Giboudeaux <christophe@krop.fr>
- Spec cleanup.
- Use %%_libexecdir where needed.
* Sun Oct 31 2021 Dmitry Sidorov <jonmagon@gmail.com>
- Update to version 2.3.0
  * Added measurement time limit
  * Fixed display of units above bars
  * The pause between tests selector has been moved to the settings window
  * Default value for threads of the first RND test is now one
* Tue Jul 27 2021 Dmitry Sidorov <jonmagon@gmail.com>
- Update to version 2.2.1
  * Hindi localization.
  * Display the text of the KAuth error that occurred.
  * Using the ISO 8601 date format
  * Fix HiDPI issue.
* Sat Feb 20 2021 Dmitry Sidorov <jonmagon@gmail.com>
- Update to version 2.2.0
  * The ability to drop pagecache before doing a test job (using K5Auth).
* Thu Jan 28 2021 andy great <andythe_great@pm.me>
- Update to version 2.1.1.
  * Fix directory selection.
- Remove explicit-lib-dependency libaio.
* Wed Dec 30 2020 Dmitry Sidorov <jonmagon@gmail.com>
- Spanish (Mexico), Slovak, Polish, Ukrainian localization
- Allow selecting the UI language: Help > Language
- Prevent adding the same directory multiple times
- Hide status bar
- Fix directory selection dialog
- Fix benchmark won't run
* Thu Nov 19 2020 Dmitry Sidorov <jonmagon@gmail.com>
- Initial, 2.0.0
